==> aria2-1.16.0.tar.gz: aria2-1.16.0/src/DownloadResult.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_DOWNLOAD_RESULT_H
#define D_DOWNLOAD_RESULT_H

#include "common.h"

#include <stdint.h>

#include <string>
#include <vector>

#include "SharedHandle.h"
#include "error_code.h"
#include "RequestGroup.h"

namespace aria2 {

class Option;
class FileEntry;
class MetadataInfo;

struct DownloadResult
{
  a2_gid_t gid;

  std::vector<SharedHandle<FileEntry> > fileEntries;

  bool inMemoryDownload;

  uint64_t sessionDownloadLength;

  // milliseconds
  int64_t sessionTime;

  error_code::Value result;

  // This field contains GIDs. See comment in
  // RequestGroup.cc::followedByGIDs_.
  std::vector<a2_gid_t> followedBy;

  // This field contains GID. See comment in
  // RequestGroup.cc::belongsToGID_.
  a2_gid_t belongsTo;

  SharedHandle<Option> option;

  SharedHandle<MetadataInfo> metadataInfo;

  int64_t totalLength;

  int64_t completedLength;

  int64_t uploadLength;

  std::string bitfield;

  std::string infoHash;

  int32_t pieceLength;

  size_t numPieces;

  std::string dir;

  DownloadResult();
  ~DownloadResult();

  // Don't allow copying
  DownloadResult(const DownloadResult& c);
  DownloadResult& operator=(const DownloadResult& c);
};

} // namespace aria2

#endif // D_DOWNLOAD_RESULT_H

==> aria2-1.18.1.tar.gz: aria2-1.18.1/src/DownloadResult.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_DOWNLOAD_RESULT_H
#define D_DOWNLOAD_RESULT_H

#include "common.h"

#include <stdint.h>

#include <string>
#include <vector>
#include <memory>

#include "error_code.h"
#include "RequestGroup.h"

namespace aria2 {

class Option;
class FileEntry;
class MetadataInfo;

struct DownloadResult
{
  std::shared_ptr<GroupId> gid;

  std::vector<std::shared_ptr<FileEntry> > fileEntries;

  bool inMemoryDownload;

  uint64_t sessionDownloadLength;

  // milliseconds
  int64_t sessionTime;

  error_code::Value result;

  // This field contains GIDs. See comment in
  // RequestGroup.cc::followedByGIDs_.
  std::vector<a2_gid_t> followedBy;

  // This field contains GID. See comment in
  // RequestGroup.cc::belongsToGID_.
  a2_gid_t belongsTo;

  std::shared_ptr<Option> option;

  std::shared_ptr<MetadataInfo> metadataInfo;

  int64_t totalLength;

  int64_t completedLength;

  int64_t uploadLength;

  std::string bitfield;

  std::string infoHash;

  int32_t pieceLength;

  size_t numPieces;

  std::string dir;

  DownloadResult();
  ~DownloadResult();

  // Don't allow copying
  DownloadResult(const DownloadResult& c);
  DownloadResult& operator=(const DownloadResult& c);
};

} // namespace aria2

#endif // D_DOWNLOAD_RESULT_H
